@@ -1,8 +1,8 @@
 /*
     beer.h - Frontend for SAFT for X11
-    Copyright (c) 1999  Martin Schulze <joey@infodrom.north.de>
+    Copyright (c) 1999,2006  Joey Schulze <joey@infodrom.org>
 
-    This file is part of the `beer' package.
+    This file is part of the Gerstensaft package.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,19 +22,28 @@
 #ifndef __BEER_H__
 #define __BEER_H__
 
+#include <stdint.h>
 #include <gtk/gtk.h>
 
 /* Contains the name of the program and version */
 extern char progname[];
 extern char version[];
 
+#define PROTOCOL_AUTO 1
+#define PROTOCOL_IPV4 2
+#define PROTOCOL_IPV6 3
+
 struct s_conf {
   GList *addrs;
+  uint8_t keep;
+  uint8_t closewindow;
+  uint8_t protocol;
+  uint8_t dotfiles;
 };
 
 extern struct s_conf config;
 
-void config_clear_history ();
+void clear_history ();
 
 /* Contains the exit code set somewhere within the program */
 extern int beer_exitcode;
