@@ -1,6 +1,6 @@
 /*
     io.h - I/O routines
-    Copyright (c) 1999  Martin Schulze <joey@infodrom.north.de>
+    Copyright (c) 1999,2006  Joey Schulze <joey@infodrom.org>
 
     This file is part of the Gerstensaft package.
 
@@ -22,11 +22,11 @@
 #ifndef __IO_H__
 #define __IO_H__
 
-#include "io.h"
+#include <sys/types.h>
 
 struct s_file {
   char *name;
-  int size;
+  off_t size;
   int type;
   struct s_file *next;
 };
@@ -48,8 +48,12 @@ char *check_and_adjust_dir (const char *dir);
 
 int list_contains_file (char **list, int length, const char *dir, const char *file);
 
+int exists (const char *dir, const char *file);
+
 int is_dir (const char *dir, const char *file);
 
 unsigned long int get_filesize (const char *name);
 
+char *escape_quotes (char *text);
+
 #endif /* __IO_H__ */
