@@ -1,6 +1,6 @@
 /*
     saft.h - SAFT interface
-    Copyright (c) 1999  Martin Schulze <joey@infodrom.north.de>
+    Copyright (c) 1999,2006  Joey Schulze <joey@infodrom.org>
 
     This file is part of the Gerstensaft package.
 
@@ -22,6 +22,6 @@
 #ifndef __SAFT_H__
 #define __SAFT_H__
 
-void saft_send (const char *addr, char **files);
+int saft_send (const char *addr, char **files, const char *comment);
 
 #endif /* __SAFT_H__ */
