@@ -1,6 +1,6 @@
 /*
-    sned.h - Provide the send dialog and related routines
-    Copyright (c) 1999  Martin Schulze <joey@infodrom.north.de>
+    send.h - Provide the send dialog and related routines
+    Copyright (c) 1999,2006  Joey Schulze <joey@infodrom.org>
 
     This file is part of the Gerstensaft package.
 
@@ -26,17 +26,23 @@
 #include "main.h"
 
 struct s_send_data {
-  int numfiles;
-  int *selected;
-  unsigned int numselected;
   int addrok;
 
+  GtkWidget *dialog;
   GtkWidget *listbox;
   GtkCombo *addrinput;
+  GtkWidget *comment;
   GtkWidget *sendbutton;
+  GtkWidget *clearbutton;
   struct s_main_data *wdata;
 };
 
-void send_dialog (int num, char **files, unsigned long int *size, gpointer data);
+void send_dialog (gpointer data);
+
+gint send_history_add (const gchar *addr, GtkCombo *combo);
+
+int sendmsg (const char *addr, char *text);
+
+int sendmessage (const char *addr, char *text);
 
 #endif /* __SEND_H__ */
